/*-----------------------------------------------------------------------*
  File........: protea.i
  Description : An include file that starts the protea super procedure and
                defines some functions to implement the TEA encryption
                algorithm.
  Input Param : <none>
  Output Param: <none>
  Author......: TEA was invented by by David Wheeler and Roger Needham of
                the Cambridge Computer Laboratory.  It was implemented in Progress
                4GL by Brian Tawney (btawney@cornerstar.com).
  Created.....: 09/24/2003
  Notes.......: If you make changes to this program that others could benefit
                from, please share your code with me: btawney@cornerstar.com.
                
                For more on the TEA algorithm, see protea.p
 
                encipher(string, key) returns character
                    This function takes a key of up to 16 characters and a
                    string of any length and returns an enciphered
                    representation of the string.

                decipher(string, key) returns character
                    This function takes a key of up to 16 characters and
                    a representation of an enciphered string and
                    returns the plaintext string.
 
                set_mix(integer) returns logical
                    This function sets the mix variable, if possible.  It
                    returns true if a valid mix value was passed in,
                    otherwise it returns false.  The mix variable is the
                    number of iterations over which to encrypt the data.
                    This number may be from 1 to 32, and is set to 32 by default.
                    The bigger the number, the slower the encryption process
                    but the better the encryption.
 
  Usage.......: {protea.i}
  
                set_mix(16).
                ASSIGN
                    <encoded text> = encipher(<plain text>,<key>)
                    <plain text> = decipher(<encoded text>,<key>)
                    .
                    
 *-----------------------------------------------------------------------*/

/*  tea.p is a self-registering super-procedure */
RUN protea.p PERSISTENT.

/*  Encipher a string and return an encoded hexadecimal string */
FUNCTION encipher RETURNS CHARACTER (CHARACTER, CHARACTER) IN SUPER.

/*  Decipher an encoded hexadecimal string and return the decoded string. */
FUNCTION decipher RETURNS CHARACTER (CHARACTER, CHARACTER) IN SUPER.

/*  Set the mix variable. */
FUNCTION set_mix RETURNS LOGICAL (INTEGER) IN SUPER.
